
rm(list = ls())

library(ggExtra)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(patchwork)
library(data.table)
library(ggpubr)
library(sf)
library(EnvStats)
# install.packages("ggpubr")


      ############## DROPLETS IMAGES - TIMEPOINTS ANALYSIS ##############



### ==========================================================
###            Import data frame + post-processing 
### ==========================================================


######## set working directory ########
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()


DropletsF = read.table(paste0(getwd(),"/Figure4&S7&S8/results_plots/droplet_results.csv"), sep = "," , header = T)
head(DropletsF)

### Add 'mono/mix' column
DropletsF2 <- DropletsF %>% 
  mutate(NbSpecies = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 | Fluo1Sum > 0 & Fluo2Sum == 0 ~ "mono", 
    Fluo1Sum == 0 & Fluo2Sum == 0 ~ "medium",
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "mix"
  )) %>% 
  ### Add 'Species' column
  mutate(Species = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 ~ 'SW',
    Fluo1Sum > 0 & Fluo2Sum == 0 ~ 'L15',
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "SW L15"
  )) %>%
  mutate(factor = fct_relevel(NbSpecies, "mono", "mix","medium")) # Add a 'factor' column to plot mono-culture before mix-culture



### Normalize both fluorescent signals based on median signal in mono-culture droplets

# Set productivity thresholds filter out 'non-growing' droplets in mono-cultures 
# when estimating the median productivity in mono-culture

threshold_L15 <- 1e+06
threshold_SW <- 1e+05

# Calculate median productivity in mono-cultures for each replicate
list.rep <- unique(DropletsF2$BiologicalRep)
list.medians.SW <- plyr::ldply(list.rep, function(r) {
  bio_rep <- r
  median.SW <- median(DropletsF2[which(DropletsF2$Timepoint == 'T48' & DropletsF2$Species == 'SW' & DropletsF2$BiologicalRep == r & DropletsF2$Fluo2Sum > threshold_SW), 'Fluo2Sum'])
  df <- data.frame('BiologicalRep' = bio_rep,
                   'Median_SW_mono' = median.SW)
})
list.medians.L15 <- plyr::ldply(list.rep, function(r) {
  bio_rep <- r
  median.L15 <- median(DropletsF2[which(DropletsF2$Timepoint == 'T48' & DropletsF2$Species == 'L15' & DropletsF2$BiologicalRep == r & DropletsF2$Fluo1Sum > threshold_L15), 'Fluo1Sum']) 
  df <- data.frame('BiologicalRep' = bio_rep,
                   'Median_L15_mono' = median.L15)
})



# Normalize fluorescent signal for each replicate by the median
# of mono-cultures
# Normalize productivity by biological replicate
DropletsF2 <- DropletsF2 %>%
  left_join(list.medians.SW, by = "BiologicalRep") %>%
  mutate(norm_fluo2 = Fluo2Sum / Median_SW_mono)
DropletsF2 <- DropletsF2 %>%
  left_join(list.medians.L15, by = "BiologicalRep") %>%
  mutate(norm_fluo1 = Fluo1Sum / Median_L15_mono)



### ==========================================================
###          FIGURES - PRODUCTIVITIES, MONO AND MIX
### ==========================================================

### Normalized Productivity mono vs mix over time
prod_time1 <- ggplot(DropletsF2 %>% filter(Timepoint != 'T0', BiologicalRep == 'R1', NbSpecies == 'mix' | NbSpecies == 'mono' & Species == 'L15'),
       aes(x = factor, y = norm_fluo1)) +
  facet_grid(~Timepoint)+
  geom_jitter(color = 'magenta3', size = 2, alpha = 0.4) +
  geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), alpha = 0.1)+
  ylim(-0.5,5)+
  stat_compare_means(method = "wilcox.test") +
  xlab("condition")+
  ylab("L15 productivity (AF)")+
  stat_n_text(size=6, position = position_nudge(y = 0))+
  theme_bw()+
  ggplot(DropletsF2 %>% filter(Timepoint != 'T0', BiologicalRep == 'R1', NbSpecies == 'mix' | NbSpecies == 'mono' & Species == 'SW'),
         aes(x = factor, y = norm_fluo2)) +
  facet_grid(~Timepoint)+
  geom_jitter(color = 'Darkgreen', size = 2, alpha = 0.4) +
  geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), alpha = 0.1)+
  ylim(-0.5,5)+
  stat_compare_means(method = "wilcox.test") +
  xlab("condition")+
  ylab("SW productivity (AF)")+
  stat_n_text(size=6, position = position_nudge(y = 0))+
  theme_bw()
prod_time1

# save figure in pdf
pdf(paste0(getwd(),'/Figure4&S7&S8/results_plots/Fig4D_FigS8A_R1.pdf'), width=10 , height=4)
prod_time1
dev.off()

prod_time2 <- ggplot(DropletsF2 %>% filter(Timepoint != 'T0', BiologicalRep == 'R2', NbSpecies == 'mix' | NbSpecies == 'mono' & Species == 'L15'),
                    aes(x = factor, y = norm_fluo1)) +
  facet_grid(~Timepoint)+
  geom_jitter(color = 'magenta3', size = 2, alpha = 0.4) +
  geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), alpha = 0.1)+
  ylim(-0.5,5)+
  stat_compare_means(method = "wilcox.test") +
  xlab("condition")+
  ylab("L15 productivity (AF)")+
  stat_n_text(size=6, position = position_nudge(y = 0))+
  theme_bw()+
  ggplot(DropletsF2 %>% filter(Timepoint != 'T0', BiologicalRep == 'R2', NbSpecies == 'mix' | NbSpecies == 'mono' & Species == 'SW'),
         aes(x = factor, y = norm_fluo2)) +
  facet_grid(~Timepoint)+
  geom_jitter(color = 'Darkgreen', size = 2, alpha = 0.4) +
  geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), alpha = 0.1)+
  ylim(-0.5,5)+
  stat_compare_means(method = "wilcox.test") +
  xlab("condition")+
  ylab("SW productivity (AF)")+
  stat_n_text(size=6, position = position_nudge(y = 0))+
  theme_bw()
prod_time2
# save figure in pdf
pdf(paste0(getwd(),'/Figure4&S7&S8/results_plots/FigS8A_R2.pdf'), width=10 , height=4)
prod_time2
dev.off()

prod_time3 <- ggplot(DropletsF2 %>% filter(Timepoint != 'T0', BiologicalRep == 'R3', NbSpecies == 'mix' | NbSpecies == 'mono' & Species == 'L15'),
                    aes(x = factor, y = norm_fluo1)) +
  facet_grid(~Timepoint)+
  geom_jitter(color = 'magenta3', size = 2, alpha = 0.4) +
  geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), alpha = 0.1)+
  ylim(-0.5,5)+
  stat_compare_means(method = "wilcox.test") +
  xlab("condition")+
  ylab("L15 productivity (AF)")+
  stat_n_text(size=6, position = position_nudge(y = 0))+
  theme_bw()+
  ggplot(DropletsF2 %>% filter(Timepoint != 'T0', BiologicalRep == 'R3', NbSpecies == 'mix' | NbSpecies == 'mono' & Species == 'SW'),
         aes(x = factor, y = norm_fluo2)) +
  facet_grid(~Timepoint)+
  geom_jitter(color = 'Darkgreen', size = 2, alpha = 0.4) +
  geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), alpha = 0.1)+
  ylim(-0.5,5)+
  stat_compare_means(method = "wilcox.test") +
  xlab("condition")+
  ylab("SW productivity (AF)")+
  stat_n_text(size=6, position = position_nudge(y = 0))+
  theme_bw()
prod_time3
# save figure in pdf
pdf(paste0(getwd(),'/Figure4&S7&S8/results_plots/FigS8A_R3.pdf'), width=10 , height=4)
prod_time3
dev.off()



### NORMALIZED - SW productivity vs L15 productivity in mix - REP 1 ONLY

norm.mix.r1.48 <- ggplot(DropletsF2 %>% filter(BiologicalRep == 'R1', Timepoint == 'T48', NbSpecies == 'mix'),
                         aes(x = norm_fluo2, y = norm_fluo1)) +
  geom_point(size = 2, alpha = 0.4, color = 'steelblue4')+
  ylab("L15 - normalized productivity")+
  xlab("SW - normalized productivity")+
  theme_bw()+
  xlim(0, 4)+
  ylim(0, 4)+
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  theme(axis.text = element_text(size=21), axis.title = element_text(size=16), strip.text = element_text(size=16), plot.title = element_text(size = 18))+
  ggtitle(expression('Co-cultures droplets (t = 48h)'))
norm.mix.r1.48

pdf(paste0(getwd(),'/Figure4&S7&S8/results_plots/FigS8B_R1.pdf'), width=5 , height=5)
norm.mix.r1.48
dev.off()

norm.mix.r2.48 <- ggplot(DropletsF2 %>% filter(BiologicalRep == 'R2', Timepoint == 'T48', NbSpecies == 'mix'),
                         aes(x = norm_fluo2, y = norm_fluo1)) +
  geom_point(size = 2, alpha = 0.4, color = 'steelblue4')+
  ylab("L15 - normalized productivity")+
  xlab("SW - normalized productivity")+
  theme_bw()+
  xlim(0, 4)+
  ylim(0, 4)+
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  theme(axis.text = element_text(size=21), axis.title = element_text(size=16), strip.text = element_text(size=16), plot.title = element_text(size = 18))+
  ggtitle(expression('Co-cultures droplets (t = 48h)'))
norm.mix.r2.48

pdf(paste0(getwd(),'/Figure4&S7&S8/results_plots/FigS8B_R2.pdf'), width=5 , height=5)
norm.mix.r2.48
dev.off()

norm.mix.r3.48 <- ggplot(DropletsF2 %>% filter(BiologicalRep == 'R3', Timepoint == 'T48', NbSpecies == 'mix'),
                         aes(x = norm_fluo2, y = norm_fluo1)) +
  geom_point(size = 2, alpha = 0.4, color = 'steelblue4')+
  ylab("L15 - normalized productivity")+
  xlab("SW - normalized productivity")+
  theme_bw()+
  xlim(0, 4)+
  ylim(0, 4)+
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  theme(axis.text = element_text(size=21), axis.title = element_text(size=16), strip.text = element_text(size=16), plot.title = element_text(size = 18))+
  ggtitle(expression('Co-cultures droplets (t = 48h)'))
norm.mix.r3.48

pdf(paste0(getwd(),'/Figure4&S7&S8/results_plots/FigS8B_R3.pdf'), width=5 , height=5)
norm.mix.r3.48
dev.off()





