
rm(list = ls())

# install.packages()  #### to install new packages before opening them with 'library()'
library(ggplot2)
library(tidyverse)
library(patchwork)
library(data.table)
library(ggpubr)
library(dplyr)
library(ggExtra)
library(EnvStats)


      ############## Flow-cytometry counting - droplets and 96 well plates ##############


# Set working directory to location of script file (main folder)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()


### ======================================================================
###          IMPORT FLOW CYTOMETRY DATA FRAME + POST PROCESSING
### ======================================================================


# Import FC counting tables
r1_r2 <- read.table(paste0(getwd(),"/Raw_data/flow_cytometry/L15-SW_4mM succinate_1.5mM salicylate/fc_counting_R1_R2.csv"), sep = ";" , header = T, skip = 1)
r3 <- read.table(paste0(getwd(),"/Raw_data/flow_cytometry/L15-SW_4mM succinate_1.5mM salicylate/fc_counting_R3.csv"), sep = ";" , header = T, skip = 1)
r3 <- r3[,1:(ncol(r3) - 1)]

fc_table <- rbind(r1_r2, r3)

# post processing script
script_path2 <- paste0(getwd(),"/Figure4&S7&S8/scripts/sub_scripts/fc_counting_post_processing.R")

# Call and run the sub-script
source(script_path2)


# Calculate means cell concentrations per technical replicate
mean.tech.rep <- cell_conc %>%                                       
  group_by(Culture, Condition, BioRep, TechRep, DilutionFactor, channel) %>%                         
  summarise_at(vars(CellConcentration),             
               list(Mean.concentration = mean))

# Calculate means cell concentrations per biological replicate
mean.bio.rep <- mean.tech.rep %>%                                       
  group_by(Culture, Condition, BioRep, DilutionFactor, channel) %>%                         
  summarise_at(vars(Mean.concentration),             
               list(Mean.concentration.biorep = mean))



### ======================================================================
###                 PLOT DATA - FRAGMENTED VS SUSPENSION
### ======================================================================


# Create a mono-mix column
mean.bio.rep <- mean.bio.rep %>%
  mutate(species = case_when(
    Condition == 'SW' | Condition == 'L15' ~ 'mono',
    Condition == 'mix' ~ 'mix',
    Condition == 'media' ~ 'medium'
  ))
# Add a 'factor' column to plot mono-culture before mix-culture
mean.bio.rep <- mean.bio.rep %>%
  mutate(factor = fct_relevel(species, "mono", "mix"))

summary(mean.bio.rep)

# stats - mean comparison
 # normality - shapiro test
l15mon <- mean.bio.rep %>% filter(channel == 'mCherry', DilutionFactor == 3, Condition == 'L15'); l15mon <- l15mon$Mean.concentration.biorep
l15mix <- mean.bio.rep %>% filter(channel == 'mCherry', DilutionFactor == 3, Condition == 'mix'); l15mix <- l15mix$Mean.concentration.biorep
shapiro.test(l15mon)
shapiro.test(l15mix)
ggqqplot(l15mix)

swmon <- mean.bio.rep %>% filter(channel == 'GFP', DilutionFactor == 3, Condition == 'SW'); swmon <- swmon$Mean.concentration.biorep
swmix <- mean.bio.rep %>% filter(channel == 'GFP', DilutionFactor == 3, Condition == 'mix'); swmix <- swmix$Mean.concentration.biorep
shapiro.test(swmon)
shapiro.test(swmix)
ggqqplot(swmon)

 # homoscédasticité
var.test(l15mon, l15mix)
var.test(swmon, swmix)


# plot tech rep instead - but perform mean comp test on bio rep

# Create a mono-mix column
mean.tech.rep <- mean.tech.rep %>%
  mutate(species = case_when(
    Condition == 'SW' | Condition == 'L15' ~ 'mono',
    Condition == 'mix' ~ 'mix',
    Condition == 'media' ~ 'medium'
  ))
# Add a 'factor' column to plot mono-culture before mix-culture
mean.tech.rep <- mean.tech.rep %>%
  mutate(factor = fct_relevel(species, "mono", "mix"))

# Save in pdf
pdf(paste0(getwd(),'/Figure4&S7&S8/results_plots/Fig4_C.pdf'), height = 5, width = 6.5)

ggplot(mean.tech.rep %>% filter(channel == 'GFP', DilutionFactor == 3, Condition == 'SW' | Condition == 'mix'),
       aes(x = factor, y = Mean.concentration)) +
  geom_boxplot(col = 'Darkgreen')+
  geom_jitter(col='forestgreen', alpha=0.5) +
  stat_compare_means(method = "t.test") +###
  scale_y_log10(
    limits=c(1.0e+07, 9.0e+09),
    breaks = c(1.0e+07,1.0e+08,1.0e+09,1.0e+10),
    labels = scales::trans_format("log10", scales::math_format(10^.x)))+
  facet_grid(~ Culture) +
  theme_bw() +
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  ggtitle(expression(italic("P. putida") ~ " (24h)")) +
  ylab('Cells/ml') +
  xlab('Culture condition') +
  theme(axis.text = element_text(size=20), axis.title = element_text(size=20), strip.text = element_text(size=18),
        plot.title = element_text(size = 18))+
  
  # L15
  ggplot(mean.tech.rep %>% filter(channel == 'mCherry', DilutionFactor == 3, Condition == 'L15' | Condition == 'mix'), 
         aes(x = factor, y = Mean.concentration)) +
  geom_boxplot(col = 'magenta4')+ #deeppink4
  geom_jitter(col='magenta3', alpha=0.5) +
  stat_compare_means(method = "t.test") + ###
  scale_y_log10(
    limits=c(1.0e+07, 9.0e+09), 
    breaks = c(1.0e+07,1.0e+08,1.0e+09,1.0e+10),
    labels = scales::trans_format("log10", scales::math_format(10^.x)))+
  facet_grid(~ Culture) +
  theme_bw() +
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  ggtitle(expression(italic("P. veronii") ~ " (24h)")) +
  ylab('Cells/ml') + 
  xlab('Culture condition') +
  theme(axis.text = element_text(size=20), axis.title = element_text(size=20), strip.text = element_text(size=18),
        plot.title = element_text(size = 18))

dev.off()


