
rm(list = ls())

library(ggplot2)
library(tidyverse)
library(readxl)
library(dplyr)
library(ggpubr)

## Data preparation

### Before being imported, the well names table was manually created (see 96-well plan scheme file), and OD_GFP_mScarletI_curves.xlsx file was manually created by separating the different tables (OD600, gfp and mScarletI fluorescence measurements) into separated excel sheet, from the excel files contained in the raw data folder.

### Set working directory to location of script file (main folder)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 4)], collapse = "/")
setwd(outputPath); getwd()

# Import well-names table
well_names <- read_excel(paste0(getwd(),'/Raw_data/microplate_reader/microplate_reader_L15_SW/succinate_4mM_salicylate_1.5mM/microplate_well_annotation.xlsx'))


### Split the tables per plate. Replicate 3 was cultured on one 96-well plate, while Replicates 1 and 2 were cultured in parallel on the same plate.

wells <- well_names

# Import data
gfp <- read_excel(paste0(getwd(),'/Raw_data/microplate_reader/microplate_reader_L15_SW/succinate_4mM_salicylate_1.5mM/OD_GFP_mScarletI_curves.xlsx'), sheet = 2)
msc <- read_excel(paste0(getwd(),'/Raw_data/microplate_reader/microplate_reader_L15_SW/succinate_4mM_salicylate_1.5mM/OD_GFP_mScarletI_curves.xlsx'), sheet = 3)

head(wells)
head(gfp)


### Measurements were made every 30 minutes.

# Time step
time_step <- 30 # one measurement every 30 minutes


### Once the time-step has been defined, create a 'time' column with the timepoints in the proper unit (hour unit). Then remove the original 'Time' column which contains both hour and date.

# gfp signal
gfp <- gfp %>% 
  mutate(time = seq(1:nrow(gfp)))
gfp$time <- gfp$time*time_step/60 # convert into hours
gfp <- gfp[,!(names(gfp) %in% c('Time'))] # remove Time column
print(paste0('initial time step = ', gfp$time[1], ' hours'))
print(paste0('final time step = ', gfp$time[length(gfp$time)], ' hours'))

# mScarletI signal
msc <- msc %>% 
  mutate(time = seq(1:nrow(msc)))
msc$time <- msc$time*time_step/60 # convert into hours
msc <- msc[,!(names(msc) %in% c('Time'))] # remove Time column
print(paste0('initial time step = ', msc$time[1], ' hours'))
print(paste0('final time step = ', msc$time[length(msc$time)], ' hours'))


### Pivot dataframe to 'long' format and fuse both plate dataframes

# Change to long dataframe format
gfp <- gfp %>% 
  pivot_longer(
    cols = colnames(gfp[,1]):colnames(gfp[,ncol(gfp)-1]), # pivot to long format for the first to the for-last columns
    names_to = "well_ID",
    values_to = "gfp_signal")

msc <- msc %>% 
  pivot_longer(
    cols = colnames(msc[,1]):colnames(msc[,ncol(msc)-1]), # pivot to long format for the first to the for-last columns
    names_to = "well_ID",
    values_to = "mScarletI_signal")

# add plate id
gfp <- gfp %>% mutate(plate_id = 1)
msc <- msc %>% mutate(plate_id = 1)

# Concatenate dataframes
gfp_growth <- rbind(gfp) %>% 
  mutate(well_name =  rep(NA, nrow(.)))
msc_growth <- rbind(msc) %>% 
  mutate(well_name =  rep(NA, nrow(.)))


### Now we add the associated well name column (and thereby annotate which condition it corresponds to) to each well-ID.

gfp_growth2 = gfp_growth
msc_growth2 = msc_growth
well_names2 = well_names

# Make a merged plate ID and well ID column
gfp_growth2$mergecol_id = paste0(gfp_growth2$plate_id, "_", gfp_growth2$well_ID)
msc_growth2$mergecol_id = paste0(msc_growth2$plate_id, "_", msc_growth2$well_ID)
well_names2$mergecol_id = paste0(well_names$plate_id, "_", well_names$well_ID)

# Then associate well names to each merged plate and well ID
for (n in well_names2$mergecol_id) {
  
  gfp_growth2[which(gfp_growth2$mergecol_id == n), 'well_name'] <- well_names2[well_names2$mergecol_id == n,'well_name']
  
  msc_growth2[which(msc_growth2$mergecol_id == n), 'well_name'] <- well_names2[well_names2$mergecol_id == n,'well_name']
}


### Split well name information into sub columns

gfp_growth2 <- gfp_growth2 %>% separate(well_name, c('bio_replicate', 'Condition', 'tech_replicate'))
msc_growth2 <- msc_growth2 %>% separate(well_name, c('bio_replicate', 'Condition', 'tech_replicate'))


# Plot growth curves

g_L15 <- ggplot(msc_growth2 %>% filter(Condition == 'L15'), 
                aes(x = time, y = mScarletI_signal, group = mergecol_id, color = Condition))+
  facet_grid(~bio_replicate)+
  geom_line(alpha=0.5, linewidth = 0.8, color = 'Magenta4')+
  geom_line(data = msc_growth2 %>% filter(Condition == 'L15SW'), alpha=0.5, linewidth = 0.8, color = 'Plum2')+
  xlab('time (h)')+
  ylab('mScarletI - Fluorescence')+
  ggtitle("Pseudomonas L15")+
  theme_bw()+
  theme(plot.title = element_text(size=10),
        axis.title = element_text(size = 10), 
        axis.text = element_text(size = 10))


g_SW <- ggplot(gfp_growth2 %>% filter(Condition == 'SW'), 
               aes(x = time, y = gfp_signal, group = mergecol_id, color = Condition))+
  #geom_line( alpha=0.5, linewidth = 0.8)+
  facet_grid(~bio_replicate)+
  geom_line(alpha=0.5, linewidth = 0.8, color = 'Darkgreen')+
  geom_line(data = gfp_growth2 %>% filter(Condition == 'L15SW'), alpha=0.5, linewidth = 0.8, color = 'yellow4')+
  xlab('time (h)')+
  ylab('gfp - Fluorescence')+
  ggtitle("Sphingomonas wittichii")+
  theme_bw()+
  theme(plot.title = element_text(size=10),
        axis.title = element_text(size = 10), 
        axis.text = element_text(size = 10))

p_curves <- ggarrange(g_SW, g_L15,
                      ncol = 1,
                      nrow = 2,
                      widths = c(4,4),
                      align = "h",
                      common.legend = TRUE)
p_curves


g_L15_log <- ggplot(msc_growth2 %>% filter(Condition == 'L15'), 
                    aes(x = time, y = log(mScarletI_signal), group = mergecol_id, color = Condition))+
  facet_grid(~bio_replicate)+
  geom_line(alpha=0.5, linewidth = 0.8, color = 'Magenta4')+
  geom_line(data = msc_growth2 %>% filter(Condition == 'L15SW'), alpha=0.5, linewidth = 0.8, color = 'Plum2')+
  xlab('time (h)')+
  ylab('mScarletI - Fluorescence')+
  ggtitle("Pseudomonas L15")+
  theme_bw()+
  theme(plot.title = element_text(size=10),
        axis.title = element_text(size = 10), 
        axis.text = element_text(size = 10))


g_SW_log <- ggplot(gfp_growth2 %>% filter(Condition == 'SW'), 
                   aes(x = time, y = log(gfp_signal), group = mergecol_id, color = Condition))+
  #geom_line( alpha=0.5, linewidth = 0.8)+
  facet_grid(~bio_replicate)+
  geom_line(alpha=0.5, linewidth = 0.8, color = 'Darkgreen')+
  geom_line(data = gfp_growth2 %>% filter(Condition == 'L15SW'), alpha=0.5, linewidth = 0.8, color = 'yellow4')+
  xlab('time (h)')+
  ylab('gfp - Fluorescence')+
  ggtitle("Sphingomonas wittichii")+
  theme_bw()+
  theme(plot.title = element_text(size=10),
        axis.title = element_text(size = 10), 
        axis.text = element_text(size = 10))

p_curves_log <- ggarrange(g_SW_log, g_L15_log,
                          ncol = 1,
                          nrow = 2,
                          widths = c(4,4),
                          align = "h",
                          common.legend = TRUE)
p_curves_log

# save plot
ggsave(paste0(getwd(),'/Figure4&S7&S8/results_plots/Fig4_A.pdf'), plot = p_curves_log, width = 8, height = 5.5)

